==> speech-analytic-testing_2.1.3_database.tar.gz: database/mssql/procedures/GetIntents.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetIntents] (
	@VCC Varchar(50) = NULL, 
	@AppId VARCHAR(100) = NULL,
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@Intents NVARCHAR(MAX)
	)
AS
BEGIN
	
	DECLARE @COGNITIVE_ENGINE VARCHAR(5) = NULL
	DECLARE @SQL NVARCHAR(MAX)

	-- DETERMINAMOS EL MOTOR COGNITIVO DEL VCC
	SELECT @COGNITIVE_ENGINE = N.[CognitiveEngine]
		FROM [dbo].[NLU] N (NOLOCK)
		WHERE N.[VCC] = @VCC
			AND N.[AppId] = @AppId
	
	SET @SQL = '
	SET NOCOUNT ON
	SELECT [Name]						    ''name'',
	        [AppId]                         ''appId'',
			[IntentId]						''intentId'',
			[Color]							''color'',
			[CreatedDate]					''createdDate'',
			[CreatedByUserId]				''createdByUserId'',
			[LastModifiedDate]				''lastModifiedDate'',
			[LastModifiedByUserId]			''lastModifiedByUserId'',
			[Status]                        ''status'',
			[StatusCode]                    ''statusCode''
		FROM [dbo].[Intent] (NOLOCK)
		WHERE [VCC] = ''' + @VCC + '''
			AND [AppId] = ''' + @AppId + ''' '

	-- PARA NLUS DE LUIS, FILTRAMOS SEGUN EL INPUT
	IF @COGNITIVE_ENGINE = 'LUIS'
	BEGIN
		SET @SQL +=	'
			AND [IntentId] IN (''' + @Intents + ''') '
	END

	IF @SearchCriteria IS NOT NULL AND @SearchExpression IS NOT NULL
	BEGIN
		SET @SQL +=	'
			AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END '
	END

	SET @SQL +=	'
		ORDER BY [LastModifiedDate] ASC, [Name] DESC '

	SET @SQL += ' 
	SET NOCOUNT OFF'

	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetIntents.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetIntents] (
	@VCC Varchar(50) = NULL, 
	@AppId VARCHAR(100) = NULL,
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@Intents NVARCHAR(MAX)
	)
AS
BEGIN
	
	DECLARE @COGNITIVE_ENGINE VARCHAR(5) = NULL
	DECLARE @SQL NVARCHAR(MAX)

	-- DETERMINAMOS EL MOTOR COGNITIVO DEL VCC
	SELECT @COGNITIVE_ENGINE = N.[CognitiveEngine]
		FROM [dbo].[NLU] N (NOLOCK)
		WHERE N.[VCC] = @VCC
			AND N.[AppId] = @AppId
	
	SET @SQL = '
	SET NOCOUNT ON
	SELECT [Name]						    ''name'',
	        [AppId]                         ''appId'',
			[IntentId]						''intentId'',
			[Color]							''color'',
			[CreatedDate]					''createdDate'',
			[CreatedByUserId]				''createdByUserId'',
			[LastModifiedDate]				''lastModifiedDate'',
			[LastModifiedByUserId]			''lastModifiedByUserId'',
			[Status]                        ''status'',
			[StatusCode]                    ''statusCode'',
			IIF(
				EXISTS(
					SELECT 1 
						FROM [dbo].[Utterance] 
						WHERE [VCC] = [dbo].[Intent].[VCC] 
							and [AppId] = [dbo].[Intent].[AppId] 
							and [IntentId] = [dbo].[Intent].[IntentId]), 
				1, 
				0
			)								''hasUtterances''
		FROM [dbo].[Intent] (NOLOCK)
		WHERE [VCC] = ''' + @VCC + '''
			AND [AppId] = ''' + @AppId + ''' '

	-- PARA NLUS DE LUIS, FILTRAMOS SEGUN EL INPUT
	IF @COGNITIVE_ENGINE = 'LUIS'
	BEGIN
		SET @SQL +=	'
			AND [IntentId] IN (''' + @Intents + ''') '
	END

	IF @SearchCriteria IS NOT NULL AND @SearchExpression IS NOT NULL
	BEGIN
		SET @SQL +=	'
			AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END '
	END

	SET @SQL +=	'
		ORDER BY [LastModifiedDate] ASC, [Name] DESC '

	SET @SQL += ' 
	SET NOCOUNT OFF'

	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
